==> kibana-7.9.1.tgz: kibana/src/plugins/telemetry/server/telemetry_collection/register_collection.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerCollection = registerCollection;

var _get_local_stats = require("./get_local_stats");

var _get_cluster_stats = require("./get_cluster_stats");

var _get_local_license = require("./get_local_license");

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at..
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
function registerCollection(telemetryCollectionManager, esCluster) {
  telemetryCollectionManager.setCollection({
    esCluster,
    title: 'local',
    priority: 0,
    statsGetter: _get_local_stats.getLocalStats,
    clusterDetailsGetter: _get_cluster_stats.getClusterUuids,
    licenseGetter: _get_local_license.getLocalLicense
  });
}

==> kibana-7.10.0.tgz: kibana/src/plugins/telemetry/server/telemetry_collection/register_collection.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerCollection = registerCollection;

var _get_local_stats = require("./get_local_stats");

var _get_cluster_stats = require("./get_cluster_stats");

var _get_local_license = require("./get_local_license");

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at..
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
function registerCollection(telemetryCollectionManager, esCluster, esClientGetter) {
  telemetryCollectionManager.setCollection({
    esCluster,
    esClientGetter,
    title: 'local',
    priority: 0,
    statsGetter: _get_local_stats.getLocalStats,
    clusterDetailsGetter: _get_cluster_stats.getClusterUuids,
    licenseGetter: _get_local_license.getLocalLicense
  });
}
